import request from '@/utils/request';

/**
 * 收藏接口 - 查询收藏列表
 * @returns
 */
export function maintainFavoritePaging(data) {
  return request({
    url: '/maintain/favorites',
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 收藏接口 - 查询用户收藏商品列表
 * @returns
 */
export function getFavouriteGoods(data) {
  return request({
    url: '/maintain/favorites/goods',
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 优惠券接口 - 查询优惠券分页
 * @returns
 */
export function maintainCouponPaging(data) {
  return request({
    url: '/maintain/coupon/paging',
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 优惠券领取记录接口 - 领取优惠券
 * @returns
 */
export function acceptConpons(couponId) {
  return request({
    url: `/maintain/usercoupon/${couponId}/claim`,
    method: 'post',
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 优惠券领取记录接口 - 获取用户领取的优惠券列表
 * @returns
 */
export function getUserAcceptCouponsList(data) {
  return request({
    url: '/maintain/usercoupons',
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 优惠券接口 - 根据商家ID查询优惠券分页
 * @returns
 */
export function accountTotIdGetConponList(merchantId,data) {
  return request({
    url: `/maintain/coupon/${merchantId}/paging`,
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 预约接口 - 查询用户预约列表
 * @returns
 */
export function maintainReservations(data) {
  return request({
    url: '/maintain/reservations',
    method: 'get',
    data: data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * 获取 - 我的客服中心
 * @returns
 */
export function getProbleList(data) {
  return request({
    url: `/maintain/problem/list`,
    method: 'post',
    data:data,
    headers: {
      'content-type': 'application/json',
    },
  });
}

/**
 * 获取 - 我的客服中心
 * @returns
 */
export function getMyTeam(data) {
  return request({
    url: `/maintain/invite/team/page`,
    method: 'get',
    data:data,
    headers: {
      'content-type': 'application/x-www-form-urlencoded',
    },
  });
}


/**
 * 意见反馈接口 - 新增意见反馈
 * @returns
 */
export function getFeedback(data) {
  return request({
    url: `/maintain/feedback`,
    method: 'post',
    data:data,
    headers: {
      'content-type': 'application/json',
    },
  });
}

/**
 * 意见反馈接口 - 新增意见反馈
 * @returns
 */
export function inviteBind(data) {
  return request({
    url: `/maintain/invite/bind`,
    method: 'post',
    data:data,
    headers: {
      'content-type': 'application/json',
    },
  });
}
